import os
from setuptools import setup, find_packages

def read_requirements(file):
    with open(file) as f:
        return [line.strip() for line in f if line.strip() and not line.startswith('#')]

def read_file(file):
   with open(file) as f:
        return f.read()

def update_init_version(version):
    init_path = os.path.join('helpr', '__init__.py')
    with open(init_path, 'r') as f:
        content = f.read()
    
    # Replace version line with new version
    import re
    new_content = re.sub(
        r"__version__\s*=\s*['\"]([^'\"]*)['\"]",
        f'__version__ = "{version}"',
        content
    )
    
    with open(init_path, 'w') as f:
        f.write(new_content)
    
long_description = read_file("README.rst")
version = read_file("VERSION").strip()
requirements = read_requirements("requirements.txt")


update_init_version(version)

setup(
    name = 'helpr',
    version = version,
    author = 'Clinikally',
    author_email = 'puneetsrivastava@clinikally.com',
    url = 'https://github.com/clinikally/helpr',
    description = 'A Python package to help you with your daily tasks',
    long_description_content_type = "text/x-rst",
    long_description = long_description,
    license = "MIT license",
    packages = find_packages(),
    package_dir = {"": "."},
    install_requires = requirements,
    python_requires = ">=3.7",
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ]
)